@@ -10,19 +10,23 @@ extern NSString *CSFileErrorException;
 @interface CSFileHandle:CSHandle
 {
 	FILE *fh;
+	NSString *path;
 	BOOL close;
 
 	NSLock *multilock;
-	CSFileHandle *parent;
+	CSFileHandle *fhowner;
 	off_t pos;
 }
 
 +(CSFileHandle *)fileHandleForReadingAtPath:(NSString *)path;
 +(CSFileHandle *)fileHandleForWritingAtPath:(NSString *)path;
 +(CSFileHandle *)fileHandleForPath:(NSString *)path modes:(NSString *)modes;
++(CSFileHandle *)fileHandleForStandardInput;
++(CSFileHandle *)fileHandleForStandardOutput;
++(CSFileHandle *)fileHandleForStandardError;
 
 // Initializers
--(id)initWithFilePointer:(FILE *)file closeOnDealloc:(BOOL)closeondealloc name:(NSString *)descname;
+-(id)initWithFilePointer:(FILE *)file closeOnDealloc:(BOOL)closeondealloc path:(NSString *)filepath;
 -(id)initAsCopyOf:(CSFileHandle *)other;
 -(void)dealloc;
 -(void)close;
@@ -41,6 +45,8 @@ extern NSString *CSFileErrorException;
 -(int)readAtMost:(int)num toBuffer:(void *)buffer;
 -(void)writeBytes:(int)num fromBuffer:(const void *)buffer;
 
+-(NSString *)name;
+
 // Internal methods
 -(void)_raiseError;
 -(void)_setMultiMode;
