@@ -7,6 +7,8 @@
 
 @interface NSDate (XAD)
 
++(NSDate *)XADDateWithYear:(int)year month:(int)month day:(int)day
+hour:(int)hour minute:(int)minute second:(int)second timeZone:(NSTimeZone *)timezone;
 +(NSDate *)XADDateWithTimeIntervalSince2000:(NSTimeInterval)interval;
 +(NSDate *)XADDateWithTimeIntervalSince1904:(NSTimeInterval)interval;
 +(NSDate *)XADDateWithTimeIntervalSince1601:(NSTimeInterval)interval;
@@ -24,8 +26,10 @@
 #endif
 
 #ifdef __APPLE__
+#ifdef __UTCUTILS__
 -(UTCDateTime)UTCDateTime;
 #endif
+#endif
 
 #ifdef __MINGW32__
 -(FILETIME)FILETIME;
