@@ -1,5 +1,6 @@
 #include "Decompressor.h"
 #include "LZMA.h"
+#include "../ClangAnalyser.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -774,7 +775,7 @@ static unsigned int Category(unsigned int val)
 	if(val&0xff00) { val>>=8; cat|=8; }
 	if(val&0xf0) { val>>=4; cat|=4; }
 	if(val&0xc) { val>>=2; cat|=2; }
-	if(val&0x2) { val>>=1; cat|=1; }
+	if(val&0x2) { /*val>>=1;*/ cat|=1; }
 	return cat+1;
 }
 
@@ -1024,17 +1025,19 @@ size_t EncodeWinZipJPEGBlocksToBuffer(WinZipJPEGDecompressor *self,void *bytes,s
 static void PushEncodedValue(WinZipJPEGDecompressor *self,WinZipJPEGHuffmanTable *table,
 int value,unsigned int highbits)
 {
-	int category,bitstring;
+	unsigned int category,bitstring;
 	if(value>=0)
 	{
 		category=Category(value);
-		int mask=(1<<category)-1;
+		analyser_assert(category>=1 && category<=32);
+		unsigned int mask=(1ull<<category)-1;
 		bitstring=value&mask;
 	}
 	else
 	{
 		category=Category(-value);
-		int mask=(1<<category)-1;
+		analyser_assert(category>=1 && category<=32);
+		unsigned int mask=(1ull<<category)-1;
 		bitstring=(value&mask)-1;
 	}
 
