@@ -29,9 +29,8 @@
 
 -(id)initWithHandle:(CSHandle *)handle length:(off_t)length propertyData:(NSData *)propertydata
 {
-	if((self=[super initWithName:[handle name] length:length]))
+	if((self=[super initWithParentHandle:handle length:length]))
 	{
-		parent=[handle retain];
 		startoffs=[handle offsetInFile];
 
 		if(propertydata&&[propertydata length]>=4) baseoffset=CSUInt32LE([propertydata bytes]);
@@ -42,12 +41,6 @@
 	return self;
 }
 
--(void)dealloc
-{
-	[parent release];
-	[super dealloc];
-}
-
 -(void)resetBlockStream
 {
 	[parent seekToFileOffset:startoffs];
