@@ -3,11 +3,14 @@
 #import "Progress.h"
 #import "CRC.h"
 
+typedef uint32_t XADCRCTransformationFunction(uint32_t crc,id context);
+
 @interface XADCRCHandle:CSStreamHandle
 {
-	CSHandle *parent;
 	uint32_t crc,initcrc,compcrc;
 	const uint32_t *table;
+	XADCRCTransformationFunction *transformationfunction;
+	id transformationcontext;
 }
 
 +(XADCRCHandle *)IEEECRC32HandleWithHandle:(CSHandle *)handle
@@ -23,6 +26,8 @@ correctCRC:(uint32_t)correctcrc conditioned:(BOOL)conditioned;
 correctCRC:(uint32_t)correctcrc CRCTable:(const uint32_t *)crctable;
 -(void)dealloc;
 
+-(void)setCRCTransformationFunction:(XADCRCTransformationFunction *)function context:(id)context;
+
 -(void)resetStream;
 -(int)streamAtMost:(int)num toBuffer:(void *)buffer;
 
