@@ -29,7 +29,7 @@
 	int numchannels,currentchannel;
 }
 
--(id)initWithHandle:(CSHandle *)parent length:(off_t)length
+-(id)initWithHandle:(CSHandle *)handle length:(off_t)length
 numberOfChannels:(int)numberofchannels palette:(NSData *)palettedata;
 
 -(void)resetByteStream;
