@@ -248,7 +248,7 @@
 
 -(id)initWithHandle:(CSHandle *)handle length:(off_t)length password:(NSData *)passdata
 {
-	if((self=[super initWithHandle:handle length:length]))
+	if((self=[super initWithInputBufferForHandle:handle length:length]))
 	{
 		const uint8_t *passbytes=[passdata bytes];
 		int passlen=[passdata length];
@@ -303,7 +303,7 @@
 
 -(id)initWithHandle:(CSHandle *)handle length:(off_t)length password:(NSData *)passdata
 {
-	if((self=[super initWithHandle:handle length:length]))
+	if((self=[super initWithInputBufferForHandle:handle length:length]))
 	{
 		const uint8_t *passbytes=[passdata bytes];
 		int passlen=[passdata length];
