@@ -274,7 +274,7 @@
 
 
 
-static NSInteger SortDirectoriesByDepthAndResource(id entry1,id entry2,void *context)
+static NSComparisonResult SortDirectoriesByDepthAndResource(id entry1,id entry2,void *context)
 {
 	NSDictionary *dict1=[entry1 objectAtIndex:1];
 	NSDictionary *dict2=[entry2 objectAtIndex:1];
@@ -538,7 +538,7 @@ deferDirectories:(BOOL)defer
 		}
 	}
 
-	#if MAC_OS_X_VERSION_MIN_REQUIRED>=1050
+	#if MAC_OS_X_VERSION_MIN_REQUIRED>=1050 || __IPHONE_OS_VERSION_MIN_REQUIRED>__IPHONE_2_0
 	if([manager createDirectoryAtPath:path
 	withIntermediateDirectories:NO attributes:nil error:NULL]) return XADNoError;
 	#else
